@@ -1,7 +1,7 @@
 # ----------------------------------------------------------------------------
 # pyglet
 # Copyright (c) 2006-2008 Alex Holkner
-# Copyright (c) 2008-2019 pyglet contributors
+# Copyright (c) 2008-2020 pyglet contributors
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -32,9 +32,6 @@
 # ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 # POSSIBILITY OF SUCH DAMAGE.
 # ----------------------------------------------------------------------------
-from __future__ import print_function
-from __future__ import absolute_import
-from builtins import object
 
 import sys
 
@@ -249,7 +246,7 @@ _device_lookup = {}   # IOHIDDeviceRef to python HIDDevice object
 _element_lookup = {}  # IOHIDElementRef to python HIDDeviceElement object
 
 
-class HIDValue(object):
+class HIDValue:
     def __init__(self, valueRef):
         # Check that this is a valid IOHIDValue.
         assert valueRef
@@ -268,7 +265,7 @@ class HIDValue(object):
         self.element = HIDDeviceElement.get_element(elementRef)
 
 
-class HIDDevice(object):
+class HIDDevice:
     @classmethod
     def get_device(cls, deviceRef):
         # deviceRef is a c_void_p pointing to an IOHIDDeviceRef
@@ -345,12 +342,12 @@ class HIDDevice(object):
             kCFRunLoopDefaultMode)
 
     def _get_elements(self):
-        try:
-            cfarray = c_void_p(iokit.IOHIDDeviceCopyMatchingElements(self.deviceRef, None, 0))
-            elements = cfarray_to_list(cfarray)
-            cf.CFRelease(cfarray)
-        except:
+        cfarray = c_void_p(iokit.IOHIDDeviceCopyMatchingElements(self.deviceRef, None, 0))
+        if not cfarray:
+            # requires "Security & Privacy / Input Monitoring", see #95
             return []
+        elements = cfarray_to_list(cfarray)
+        cf.CFRelease(cfarray)
         return elements
 
     # Page and usage IDs are from the HID usage tables located at
@@ -425,7 +422,7 @@ class HIDDevice(object):
             return None
 
 
-class HIDDeviceElement(object):
+class HIDDeviceElement:
     @classmethod
     def get_element(cls, elementRef):
         # elementRef is a c_void_p pointing to an IOHIDDeviceElementRef
@@ -469,7 +466,7 @@ class HIDDeviceElement(object):
         self.physicalMax = iokit.IOHIDElementGetPhysicalMax(elementRef)
 
 
-class HIDManager(object):
+class HIDManager:
     def __init__(self):
         # Create the HID Manager.
         self.managerRef = c_void_p(iokit.IOHIDManagerCreate(None, kIOHIDOptionsTypeNone))
@@ -481,13 +478,16 @@ class HIDManager(object):
         self.devices = self._get_devices()
 
     def _get_devices(self):
-        # Tell manager that we are willing to match *any* device.
-        # (Alternatively, we could restrict by device usage, or usage page.)
-        iokit.IOHIDManagerSetDeviceMatching(self.managerRef, None)
-        # Copy the device set and convert it to python.
-        cfset = c_void_p(iokit.IOHIDManagerCopyDevices(self.managerRef))
-        devices = cfset_to_set(cfset)
-        cf.CFRelease(cfset)
+        try:
+            # Tell manager that we are willing to match *any* device.
+            # (Alternatively, we could restrict by device usage, or usage page.)
+            iokit.IOHIDManagerSetDeviceMatching(self.managerRef, None)
+            # Copy the device set and convert it to python.
+            cfset = c_void_p(iokit.IOHIDManagerCopyDevices(self.managerRef))
+            devices = cfset_to_set(cfset)
+            cf.CFRelease(cfset)
+        except:
+            return set()
         return devices
 
     def open(self):
