@@ -1,6 +1,7 @@
 # ----------------------------------------------------------------------------
 # pyglet
 # Copyright (c) 2006-2008 Alex Holkner
+# Copyright (c) 2008-2020 pyglet contributors
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -32,12 +33,6 @@
 # POSSIBILITY OF SUCH DAMAGE.
 # ----------------------------------------------------------------------------
 
-'''
-'''
-
-__docformat__ = 'restructuredtext'
-__version__ = ''
-
 from pyglet.window import key
 
 # From SDL: src/video/quartz/SDL_QuartzKeys.h
@@ -229,77 +224,76 @@ keymap = {
     QZ_KP_PERIOD: key.NUM_DECIMAL,
 }
 
-
 charmap = {
-    ' ' : key.SPACE,
-    '!' : key.EXCLAMATION,
-    '"' : key.DOUBLEQUOTE,
-    '#' : key.HASH,
-    '#' : key.POUND,
-    '$' : key.DOLLAR,
-    '%' : key.PERCENT,
-    '&' : key.AMPERSAND,
-    "'" : key.APOSTROPHE,
-    '(' : key.PARENLEFT,
-    ')' : key.PARENRIGHT,
-    '*' : key.ASTERISK,
-    '+' : key.PLUS,
-    ',' : key.COMMA,
-    '-' : key.MINUS,
-    '.' : key.PERIOD,
-    '/' : key.SLASH,
-    '0' : key._0,
-    '1' : key._1,
-    '2' : key._2,
-    '3' : key._3,
-    '4' : key._4,
-    '5' : key._5,
-    '6' : key._6,
-    '7' : key._7,
-    '8' : key._8,
-    '9' : key._9,
-    ':' : key.COLON,
-    ';' : key.SEMICOLON,
-    '<' : key.LESS,
-    '=' : key.EQUAL,
-    '>' : key.GREATER,
-    '?' : key.QUESTION,
-    '@' : key.AT,
-    '[' : key.BRACKETLEFT,
-    '\\' : key.BACKSLASH,
-    ']' : key.BRACKETRIGHT,
-    '^' : key.ASCIICIRCUM,
-    '_' : key.UNDERSCORE,
-    '`' : key.GRAVE,
-    '`' : key.QUOTELEFT,
-    'A' : key.A,
-    'B' : key.B,
-    'C' : key.C,
-    'D' : key.D,
-    'E' : key.E,
-    'F' : key.F,
-    'G' : key.G,
-    'H' : key.H,
-    'I' : key.I,
-    'J' : key.J,
-    'K' : key.K,
-    'L' : key.L,
-    'M' : key.M,
-    'N' : key.N,
-    'O' : key.O,
-    'P' : key.P,
-    'Q' : key.Q,
-    'R' : key.R,
-    'S' : key.S,
-    'T' : key.T,
-    'U' : key.U,
-    'V' : key.V,
-    'W' : key.W,
-    'X' : key.X,
-    'Y' : key.Y,
-    'Z' : key.Z,
-    '{' : key.BRACELEFT,
-    '|' : key.BAR,
-    '}' : key.BRACERIGHT,
-    '~' : key.ASCIITILDE
+    ' ': key.SPACE,
+    '!': key.EXCLAMATION,
+    '"': key.DOUBLEQUOTE,
+    '#': key.HASH,
+    '#': key.POUND,
+    '$': key.DOLLAR,
+    '%': key.PERCENT,
+    '&': key.AMPERSAND,
+    "'": key.APOSTROPHE,
+    '(': key.PARENLEFT,
+    ')': key.PARENRIGHT,
+    '*': key.ASTERISK,
+    '+': key.PLUS,
+    ',': key.COMMA,
+    '-': key.MINUS,
+    '.': key.PERIOD,
+    '/': key.SLASH,
+    '0': key._0,
+    '1': key._1,
+    '2': key._2,
+    '3': key._3,
+    '4': key._4,
+    '5': key._5,
+    '6': key._6,
+    '7': key._7,
+    '8': key._8,
+    '9': key._9,
+    ':': key.COLON,
+    ';': key.SEMICOLON,
+    '<': key.LESS,
+    '=': key.EQUAL,
+    '>': key.GREATER,
+    '?': key.QUESTION,
+    '@': key.AT,
+    '[': key.BRACKETLEFT,
+    '\\': key.BACKSLASH,
+    ']': key.BRACKETRIGHT,
+    '^': key.ASCIICIRCUM,
+    '_': key.UNDERSCORE,
+    '`': key.GRAVE,
+    '`': key.QUOTELEFT,
+    'A': key.A,
+    'B': key.B,
+    'C': key.C,
+    'D': key.D,
+    'E': key.E,
+    'F': key.F,
+    'G': key.G,
+    'H': key.H,
+    'I': key.I,
+    'J': key.J,
+    'K': key.K,
+    'L': key.L,
+    'M': key.M,
+    'N': key.N,
+    'O': key.O,
+    'P': key.P,
+    'Q': key.Q,
+    'R': key.R,
+    'S': key.S,
+    'T': key.T,
+    'U': key.U,
+    'V': key.V,
+    'W': key.W,
+    'X': key.X,
+    'Y': key.Y,
+    'Z': key.Z,
+    '{': key.BRACELEFT,
+    '|': key.BAR,
+    '}': key.BRACERIGHT,
+    '~': key.ASCIITILDE
 }
