@@ -1,7 +1,38 @@
-#!/usr/bin/python
-# $Id:$
+# ----------------------------------------------------------------------------
+# pyglet
+# Copyright (c) 2006-2008 Alex Holkner
+# Copyright (c) 2008-2020 pyglet contributors
+# All rights reserved.
+#
+# Redistribution and use in source and binary forms, with or without
+# modification, are permitted provided that the following conditions
+# are met:
+#
+#  * Redistributions of source code must retain the above copyright
+#    notice, this list of conditions and the following disclaimer.
+#  * Redistributions in binary form must reproduce the above copyright
+#    notice, this list of conditions and the following disclaimer in
+#    the documentation and/or other materials provided with the
+#    distribution.
+#  * Neither the name of pyglet nor the names of its
+#    contributors may be used to endorse or promote products
+#    derived from this software without specific prior written
+#    permission.
+#
+# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
+# FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
+# COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
+# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
+# BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
+# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
+# CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
+# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
+# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
+# POSSIBILITY OF SUCH DAMAGE.
+# ----------------------------------------------------------------------------
 
-from __future__ import division
 import ctypes
 
 lib = ctypes.windll.wintab32
@@ -17,6 +48,7 @@ WTPKT = DWORD
 
 LCNAMELEN = 40
 
+
 class AXIS(ctypes.Structure):
     _fields_ = (
         ('axMin', LONG),
@@ -31,6 +63,7 @@ class AXIS(ctypes.Structure):
     def get_bias(self):
         return -self.axMin
 
+
 class ORIENTATION(ctypes.Structure):
     _fields_ = (
         ('orAzimuth', ctypes.c_int),
@@ -38,6 +71,7 @@ class ORIENTATION(ctypes.Structure):
         ('orTwist', ctypes.c_int)
     )
 
+
 class ROTATION(ctypes.Structure):
     _fields_ = (
         ('roPitch', ctypes.c_int),
@@ -45,6 +79,7 @@ class ROTATION(ctypes.Structure):
         ('roYaw', ctypes.c_int),
     )
 
+
 class LOGCONTEXT(ctypes.Structure):
     _fields_ = (
         ('lcName', WCHAR * LCNAMELEN),
@@ -83,7 +118,8 @@ class LOGCONTEXT(ctypes.Structure):
         ('lcSysSensY', FIX32),
     )
 
-# Custom packet format with fields 
+
+# Custom packet format with fields
 #   PK_CHANGED
 #   PK_CURSOR
 #   PK_BUTTONS
@@ -106,20 +142,21 @@ class PACKET(ctypes.Structure):
         ('pkOrientation', ORIENTATION),
     )
 
-PK_CONTEXT = 0x0001	# reporting context 
-PK_STATUS = 0x0002	# status bits 
-PK_TIME = 0x0004	# time stamp 
-PK_CHANGED = 0x0008	# change bit vector 
-PK_SERIAL_NUMBER = 0x0010	# packet serial number 
-PK_CURSOR = 0x0020	# reporting cursor 
-PK_BUTTONS = 0x0040	# button information 
-PK_X = 0x0080	# x axis 
-PK_Y = 0x0100	# y axis 
-PK_Z = 0x0200	# z axis 
-PK_NORMAL_PRESSURE = 0x0400	# normal or tip pressure 
-PK_TANGENT_PRESSURE = 0x0800	# tangential or barrel pressure 
-PK_ORIENTATION = 0x1000	# orientation info: tilts 
-PK_ROTATION = 0x2000	# rotation info; 1.1 
+
+PK_CONTEXT = 0x0001  # reporting context
+PK_STATUS = 0x0002  # status bits
+PK_TIME = 0x0004  # time stamp
+PK_CHANGED = 0x0008  # change bit vector
+PK_SERIAL_NUMBER = 0x0010  # packet serial number
+PK_CURSOR = 0x0020  # reporting cursor
+PK_BUTTONS = 0x0040  # button information
+PK_X = 0x0080  # x axis
+PK_Y = 0x0100  # y axis
+PK_Z = 0x0200  # z axis
+PK_NORMAL_PRESSURE = 0x0400  # normal or tip pressure
+PK_TANGENT_PRESSURE = 0x0800  # tangential or barrel pressure
+PK_ORIENTATION = 0x1000  # orientation info: tilts
+PK_ROTATION = 0x2000  # rotation info; 1.1
 
 TU_NONE = 0
 TU_INCHES = 1
@@ -129,7 +166,7 @@ TU_CIRCLE = 3
 # messages
 WT_DEFBASE = 0x7ff0
 WT_MAXOFFSET = 0xf
-WT_PACKET = 0 # remember to add base
+WT_PACKET = 0  # remember to add base
 WT_CTXOPEN = 1
 WT_CTXCLOSE = 2
 WT_CTXUPDATE = 3
@@ -170,11 +207,11 @@ SBN_P3DRAG = 0xF0
 HWC_INTEGRATED = 0x0001
 HWC_TOUCH = 0x0002
 HWC_HARDPROX = 0x0004
-HWC_PHYSID_CURSORS = 0x0008 # 1.1 
+HWC_PHYSID_CURSORS = 0x0008  # 1.1
 
-CRC_MULTIMODE = 0x0001 # 1.1 
-CRC_AGGREGATE = 0x0002 # 1.1 
-CRC_INVERT = 0x0004 # 1.1 
+CRC_MULTIMODE = 0x0001  # 1.1
+CRC_AGGREGATE = 0x0002  # 1.1
+CRC_INVERT = 0x0004  # 1.1
 
 WTI_INTERFACE = 1
 IFC_WINTABID = 1
@@ -202,8 +239,8 @@ STA_MAX = 8
 
 WTI_DEFCONTEXT = 3
 WTI_DEFSYSCTX = 4
-WTI_DDCTXS = 400 # 1.1 
-WTI_DSCTXS = 500 # 1.1 
+WTI_DDCTXS = 400  # 1.1
+WTI_DSCTXS = 500  # 1.1
 CTX_NAME = 1
 CTX_OPTIONS = 2
 CTX_STATUS = 3
@@ -258,8 +295,8 @@ DVC_Z = 14
 DVC_NPRESSURE = 15
 DVC_TPRESSURE = 16
 DVC_ORIENTATION = 17
-DVC_ROTATION = 18 # 1.1 
-DVC_PNPID = 19 # 1.1 
+DVC_ROTATION = 18  # 1.1
+DVC_PNPID = 19  # 1.1
 DVC_MAX = 19
 
 WTI_CURSORS = 200
@@ -277,12 +314,12 @@ CSR_NPRESPONSE = 11
 CSR_TPBUTTON = 12
 CSR_TPBTNMARKS = 13
 CSR_TPRESPONSE = 14
-CSR_PHYSID = 15 # 1.1 
-CSR_MODE = 16 # 1.1 
-CSR_MINPKTDATA = 17 # 1.1 
-CSR_MINBUTTONS = 18 # 1.1 
-CSR_CAPABILITIES = 19 # 1.1 
-CSR_TYPE = 20 # 1.2 
+CSR_PHYSID = 15  # 1.1
+CSR_MODE = 16  # 1.1
+CSR_MINPKTDATA = 17  # 1.1
+CSR_MINBUTTONS = 18  # 1.1
+CSR_CAPABILITIES = 19  # 1.1
+CSR_TYPE = 20  # 1.2
 CSR_MAX = 20
 
 WTI_EXTENSIONS = 300
@@ -294,14 +331,14 @@ EXT_AXES = 5
 EXT_DEFAULT = 6
 EXT_DEFCONTEXT = 7
 EXT_DEFSYSCTX = 8
-EXT_CURSORS = 9 
-EXT_MAX = 109 # Allow 100 cursors 
+EXT_CURSORS = 9
+EXT_MAX = 109  # Allow 100 cursors
 CXO_SYSTEM = 0x0001
 CXO_PEN = 0x0002
 CXO_MESSAGES = 0x0004
 CXO_MARGIN = 0x8000
 CXO_MGNINSIDE = 0x4000
-CXO_CSRMESSAGES = 0x0008 # 1.1 
+CXO_CSRMESSAGES = 0x0008  # 1.1
 
 # context status values 
 CXS_DISABLED = 0x0001
@@ -319,7 +356,7 @@ TPS_PROXIMITY = 0x0001
 TPS_QUEUE_ERR = 0x0002
 TPS_MARGIN = 0x0004
 TPS_GRAB = 0x0008
-TPS_INVERT = 0x0010 # 1.1 
+TPS_INVERT = 0x0010  # 1.1
 
 TBN_NONE = 0
 TBN_UP = 1
@@ -328,9 +365,9 @@ PKEXT_ABSOLUTE = 1
 PKEXT_RELATIVE = 2
 
 # Extension tags. 
-WTX_OBT = 0	# Out of bounds tracking 
-WTX_FKEYS = 1	# Function keys 
-WTX_TILT = 2	# Raw Cartesian tilt; 1.1 
-WTX_CSRMASK = 3	# select input by cursor type; 1.1 
-WTX_XBTNMASK = 4	# Extended button mask; 1.1 
-WTX_EXPKEYS = 5	# ExpressKeys; 1.3 
+WTX_OBT = 0  # Out of bounds tracking
+WTX_FKEYS = 1  # Function keys
+WTX_TILT = 2  # Raw Cartesian tilt; 1.1
+WTX_CSRMASK = 3  # select input by cursor type; 1.1
+WTX_XBTNMASK = 4  # Extended button mask; 1.1
+WTX_EXPKEYS = 5  # ExpressKeys; 1.3
