@@ -1,6 +1,7 @@
 # ----------------------------------------------------------------------------
 # pyglet
 # Copyright (c) 2006-2008 Alex Holkner
+# Copyright (c) 2008-2020 pyglet contributors
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -32,12 +33,7 @@
 # POSSIBILITY OF SUCH DAMAGE.
 # ----------------------------------------------------------------------------
 
-'''
-'''
-
-__docformat__ = 'restructuredtext'
-__version__ = '$Id: $'
-
+import sys
 import ctypes
 from ctypes import *
 from ctypes.wintypes import *
@@ -56,6 +52,11 @@ del t
 del _int_types
 
 
+# PUINT is defined only from >= python 3.2
+if sys.version_info < (3, 2)[:2]:
+    PUINT = POINTER(UINT)
+
+
 class c_void(Structure):
     # c_void_p is a buggy return type, converting to int, so
     # POINTER(None) == c_void_p is actually written as
@@ -78,6 +79,7 @@ def POINTER_(obj):
 
     return p
 
+
 c_void_p = POINTER_(c_void)
 INT = c_int
 LPVOID = c_void_p
@@ -94,6 +96,7 @@ UINT_PTR = HANDLE
 LONG_PTR = HANDLE
 HDROP = HANDLE
 LPTSTR = LPWSTR
+LPSTREAM = c_void_p
 
 LF_FACESIZE = 32
 CCHDEVICENAME = 32
@@ -104,6 +107,7 @@ TIMERPROC = WINFUNCTYPE(None, HWND, UINT, POINTER(UINT), DWORD)
 TIMERAPCPROC = WINFUNCTYPE(None, PVOID, DWORD, DWORD)
 MONITORENUMPROC = WINFUNCTYPE(BOOL, HMONITOR, HDC, LPRECT, LPARAM)
 
+
 def MAKEINTRESOURCE(i):
     return cast(ctypes.c_void_p(i & 0xFFFF), c_wchar_p)
 
@@ -122,6 +126,7 @@ class WNDCLASS(Structure):
         ('lpszClassName', c_wchar_p)
     ]
 
+
 class SECURITY_ATTRIBUTES(Structure):
     _fields_ = [
         ("nLength", DWORD),
@@ -130,6 +135,7 @@ class SECURITY_ATTRIBUTES(Structure):
     ]
     __slots__ = [f[0] for f in _fields_]
 
+
 class PIXELFORMATDESCRIPTOR(Structure):
     _fields_ = [
         ('nSize', WORD),
@@ -160,6 +166,7 @@ class PIXELFORMATDESCRIPTOR(Structure):
         ('dwDamageMask', DWORD)
     ]
 
+
 class RGBQUAD(Structure):
     _fields_ = [
         ('rgbBlue', BYTE),
@@ -169,6 +176,7 @@ class RGBQUAD(Structure):
     ]
     __slots__ = [f[0] for f in _fields_]
 
+
 class CIEXYZ(Structure):
     _fields_ = [
         ('ciexyzX', DWORD),
@@ -177,6 +185,7 @@ class CIEXYZ(Structure):
     ]
     __slots__ = [f[0] for f in _fields_]
 
+
 class CIEXYZTRIPLE(Structure):
     _fields_ = [
         ('ciexyzRed', CIEXYZ),
@@ -185,6 +194,7 @@ class CIEXYZTRIPLE(Structure):
     ]
     __slots__ = [f[0] for f in _fields_]
 
+
 class BITMAPINFOHEADER(Structure):
     _fields_ = [
         ('biSize', DWORD),
@@ -200,6 +210,7 @@ class BITMAPINFOHEADER(Structure):
         ('biClrImportant', DWORD),
     ]
 
+
 class BITMAPV5HEADER(Structure):
     _fields_ = [
         ('bV5Size', DWORD),
@@ -228,6 +239,7 @@ class BITMAPV5HEADER(Structure):
         ('bV5Reserved', DWORD),
     ]
 
+
 class BITMAPINFO(Structure):
     _fields_ = [
         ('bmiHeader', BITMAPINFOHEADER),
@@ -235,6 +247,7 @@ class BITMAPINFO(Structure):
     ]
     __slots__ = [f[0] for f in _fields_]
 
+
 class LOGFONT(Structure):
     _fields_ = [
         ('lfHeight', LONG),
@@ -253,6 +266,7 @@ class LOGFONT(Structure):
         ('lfFaceName', (c_char * LF_FACESIZE))  # Use ASCII
     ]
 
+
 class TRACKMOUSEEVENT(Structure):
     _fields_ = [
         ('cbSize', DWORD),
@@ -262,6 +276,7 @@ class TRACKMOUSEEVENT(Structure):
     ]
     __slots__ = [f[0] for f in _fields_]
 
+
 class MINMAXINFO(Structure):
     _fields_ = [
         ('ptReserved', POINT),
@@ -272,6 +287,7 @@ class MINMAXINFO(Structure):
     ]
     __slots__ = [f[0] for f in _fields_]
 
+
 class ABC(Structure):
     _fields_ = [
         ('abcA', c_int),
@@ -280,6 +296,7 @@ class ABC(Structure):
     ]
     __slots__ = [f[0] for f in _fields_]
 
+
 class TEXTMETRIC(Structure):
     _fields_ = [
         ('tmHeight', c_long),
@@ -305,6 +322,7 @@ class TEXTMETRIC(Structure):
     ]
     __slots__ = [f[0] for f in _fields_]
 
+
 class MONITORINFOEX(Structure):
     _fields_ = [
         ('cbSize', DWORD),
@@ -315,6 +333,7 @@ class MONITORINFOEX(Structure):
     ]
     __slots__ = [f[0] for f in _fields_]
 
+
 class DEVMODE(Structure):
     _fields_ = [
         ('dmDeviceName', BCHAR * CCHDEVICENAME),
@@ -354,6 +373,7 @@ class DEVMODE(Structure):
         ('dmPanningHeight', DWORD),
     ]
 
+
 class ICONINFO(Structure):
     _fields_ = [
         ('fIcon', BOOL),
@@ -364,6 +384,7 @@ class ICONINFO(Structure):
     ]
     __slots__ = [f[0] for f in _fields_]
 
+
 class RAWINPUTDEVICE(Structure):
     _fields_ = [
         ('usUsagePage', USHORT),
@@ -372,9 +393,11 @@ class RAWINPUTDEVICE(Structure):
         ('hwndTarget', HWND)
     ]
 
+
 PCRAWINPUTDEVICE = POINTER(RAWINPUTDEVICE)
 HRAWINPUT = HANDLE
 
+
 class RAWINPUTHEADER(Structure):
     _fields_ = [
         ('dwType', DWORD),
@@ -383,12 +406,14 @@ class RAWINPUTHEADER(Structure):
         ('wParam', WPARAM),
     ]
 
+
 class _Buttons(Structure):
     _fields_ = [
         ('usButtonFlags', USHORT),
         ('usButtonData', USHORT),
     ]
 
+
 class _U(Union):
     _anonymous_ = ('_buttons',)
     _fields_ = [
@@ -396,6 +421,7 @@ class _U(Union):
         ('_buttons', _Buttons),
     ]
 
+
 class RAWMOUSE(Structure):
     _anonymous_ = ('u',)
     _fields_ = [
@@ -407,6 +433,7 @@ class RAWMOUSE(Structure):
         ('ulExtraInformation', ULONG),
     ]
 
+
 class RAWKEYBOARD(Structure):
     _fields_ = [
         ('MakeCode', USHORT),
@@ -417,6 +444,7 @@ class RAWKEYBOARD(Structure):
         ('ExtraInformation', ULONG),
     ]
 
+
 class RAWHID(Structure):
     _fields_ = [
         ('dwSizeHid', DWORD),
@@ -424,6 +452,7 @@ class RAWHID(Structure):
         ('bRawData', POINTER(BYTE)),
     ]
 
+
 class _RAWINPUTDEVICEUNION(Union):
     _fields_ = [
         ('mouse', RAWMOUSE),
@@ -431,8 +460,21 @@ class _RAWINPUTDEVICEUNION(Union):
         ('hid', RAWHID),
     ]
 
+
 class RAWINPUT(Structure):
     _fields_ = [
         ('header', RAWINPUTHEADER),
         ('data', _RAWINPUTDEVICEUNION),
-    ]
\ No newline at end of file
+    ]
+
+
+# PROPVARIANT wrapper, doesn't require InitPropVariantFromInt64 this way.
+class PROPVARIANT(ctypes.Structure):
+    _fields_ = [
+        ('vt', ctypes.c_ushort),
+        ('wReserved1', ctypes.c_ubyte),
+        ('wReserved2', ctypes.c_ubyte),
+        ('wReserved3', ctypes.c_ulong),
+        ('llVal', ctypes.c_longlong),
+    ]
+
